fn derive_own_key_share(secret: &SecretKey) -> HalfKeyExpand description
Used in Proof of Relay to derive own half-key (S0)
The function samples a secp256k1 field element using the given secret via sample_field_element.
fn derive_own_key_share(secret: &SecretKey) -> HalfKeyUsed in Proof of Relay to derive own half-key (S0)
The function samples a secp256k1 field element using the given secret via sample_field_element.