pub fn generate_proof_of_relay(
secrets: &[SharedSecret],
) -> Result<(Vec<ProofOfRelayString>, ProofOfRelayValues)>Expand description
Helper function which generates proof of relay for the given path.
pub fn generate_proof_of_relay(
secrets: &[SharedSecret],
) -> Result<(Vec<ProofOfRelayString>, ProofOfRelayValues)>Helper function which generates proof of relay for the given path.