pre_verify

Function pre_verify 

pub fn pre_verify(
    secret: &SharedSecret,
    pors: &ProofOfRelayString,
    challenge: &EthereumChallenge,
) -> Result<ProofOfRelayOutput>
Verifies that an incoming packet contains all values that are necessary to reconstruct the response to redeem the incentive for relaying the packet.

Arguments

  • secret shared secret with the creator of the packet
  • pors ProofOfRelayString as included within the packet
  • challenge the ticket challenge of the incoming ticket