pub struct ProofOfRelayOutput {
pub own_key: HalfKey,
pub next_ticket_challenge: EthereumChallenge,
pub ack_challenge: HalfKeyChallenge,
}Expand description
Derivable challenge which contains the key share of the relayer as well as the secret that was used to create it and the challenge for the next relayer.
Fields
own_key: HalfKeynext_ticket_challenge: EthereumChallengeack_challenge: HalfKeyChallengeTrait Implementations
Sourceimpl Clone for ProofOfRelayOutput
impl Clone for ProofOfRelayOutput
Sourcefn clone(&self) -> ProofOfRelayOutput
fn clone(&self) -> ProofOfRelayOutput
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for ProofOfRelayOutput
impl RefUnwindSafe for ProofOfRelayOutput
impl Send for ProofOfRelayOutput
impl Sync for ProofOfRelayOutput
impl Unpin for ProofOfRelayOutput
impl UnwindSafe for ProofOfRelayOutput