ProofOfRelayValues

Struct ProofOfRelayValues 

pub struct ProofOfRelayValues([u8; 54]);
Type that contains the challenge for the first ticket sent to the first relayer.

This is the first entry of the entire PoR challenge chain generated for the packet.

Tuple Fields

0: [u8; 54]

Implementations

Source

impl ProofOfRelayValues

fn new( chain_len: u8, ack_challenge: &HalfKeyChallenge, ticket_challenge: &EthereumChallenge, ) -> Self

pub fn chain_length(&self) -> u8

Length of this PoR challenge chain (number of hops + 1).

pub fn acknowledgement_challenge(&self) -> HalfKeyChallenge

Returns the challenge that must be solved once the acknowledgement to the packet has been received.

This is the ProofOfRelayValues::ticket_challenge minus the Hint.

pub fn ticket_challenge(&self) -> EthereumChallenge

Returns the complete challenge that is present on the ticket corresponding to the packet.