pub struct SurbReceiverInfo([u8; 86]);Expand description
Wraps the ProofOfRelayValues with some additional information about the sender of the packet,
that is supposed to be passed along with the SURB.
Tuple Fields
0: [u8; 86]Implementations
Sourceimpl SurbReceiverInfo
impl SurbReceiverInfo
pub fn new(pov: ProofOfRelayValues, share: [u8; 32]) -> Self
pub fn proof_of_relay_values(&self) -> ProofOfRelayValues