ProofOfRelayValuesWithSolution

Type Alias ProofOfRelayValuesWithSolution 

pub type ProofOfRelayValuesWithSolution = (ProofOfRelayValues, HalfKey);
Contains Proof of Relay values and a solution to the first acknowledgement challenge.

This is useful when additional pre-conditioning is needed on the acknowledgement sent by the first relayer, such as in PIX.