pub fn pre_verify(
secret: &SharedSecret,
pors: &ProofOfRelayString,
challenge: &EthereumChallenge,
) -> Result<ProofOfRelayOutput>Expand description
Verifies that an incoming packet contains all values that are necessary to reconstruct the response to redeem the incentive for relaying the packet.
Arguments
secretshared secret with the creator of the packetporsProofOfRelayStringas included within the packetchallengethe ticket challenge of the incoming ticket