pub struct ProofOfRelayString([u8; 53]);Expand description
Contains the Proof of Relay challenge for the next downstream node as well as the hint that is used to verify the challenge that is given to the relayer.
Tuple Fields
0: [u8; 53]Implementations
Sourceimpl ProofOfRelayString
impl ProofOfRelayString
fn new( next_ticket_challenge: &EthereumChallenge, hint: &HalfKeyChallenge, ) -> Self
Sourcepub fn next_ticket_challenge(&self) -> EthereumChallenge
pub fn next_ticket_challenge(&self) -> EthereumChallenge
Challenge that must be printed on the ticket for the next downstream node.
Sourcepub fn acknowledgement_challenge_or_hint(&self) -> HalfKeyChallenge
pub fn acknowledgement_challenge_or_hint(&self) -> HalfKeyChallenge
Proof of Relay hint value for this node. In case this node is a sender of the packet, it contains the acknowledgement challenge.